@@ -1,4 +1,5 @@
 use crate::helpers::{self, Helpers};
+use crate::Rate;
 use core::cmp::Ordering;
 use core::convert;
 use core::ops;
@@ -228,41 +229,134 @@ macro_rules! impl_duration_for_integer {
                 if Helpers::<NOM, DENOM, O_NOM, O_DENOM>::SAME_BASE {
                     Some(Duration::<$i, O_NOM, O_DENOM>::from_ticks(self.ticks))
                 } else {
-                    if let Some(lh) = self
-                        .ticks
-                        .checked_mul(Helpers::<NOM, DENOM, O_NOM, O_DENOM>::RD_TIMES_LN as $i)
+                    if let Some(lh) = (self.ticks as u64)
+                        .checked_mul(Helpers::<NOM, DENOM, O_NOM, O_DENOM>::RD_TIMES_LN as u64)
                     {
-                        let ticks = lh / Helpers::<NOM, DENOM, O_NOM, O_DENOM>::LD_TIMES_RN as $i;
+                        let ticks = lh / Helpers::<NOM, DENOM, O_NOM, O_DENOM>::LD_TIMES_RN as u64;
 
-                        Some(Duration::<$i, O_NOM, O_DENOM>::from_ticks(ticks))
+                        if ticks <= <$i>::MAX as u64 {
+                            Some(Duration::<$i, O_NOM, O_DENOM>::from_ticks(ticks as $i))
+                        } else {
+                            None
+                        }
                     } else {
                         None
                     }
                 }
             }
 
+            /// Const try into rate, checking for divide-by-zero.
+            ///
+            /// ```
+            /// # use fugit::*;
+            #[doc = concat!("let d1 = Duration::<", stringify!($i), ", 1, 1_000>::from_ticks(2);")]
+            #[doc = concat!("let r1: Option<Rate::<", stringify!($i), ", 1, 1>> = d1.try_into_rate();")]
+            ///
+            /// assert_eq!(r1.unwrap().raw(), 500);
+            /// ```
+            pub const fn try_into_rate<const O_NOM: u32, const O_DENOM: u32>(
+                self,
+            ) -> Option<Rate<$i, O_NOM, O_DENOM>> {
+                if self.ticks > 0 {
+                    Some(Rate::<$i, O_NOM, O_DENOM>::from_raw(
+                        Helpers::<NOM, DENOM, O_NOM, O_DENOM>::RATE_TO_DURATION_NUMERATOR as $i
+                        / self.ticks
+                    ))
+                } else {
+                    None
+                }
+            }
+
+            /// Convert from duration to rate.
+            pub const fn into_rate<const O_NOM: u32, const O_DENOM: u32>(
+                self,
+            ) -> Rate<$i, O_NOM, O_DENOM> {
+                if let Some(v) = self.try_into_rate() {
+                    v
+                } else {
+                    panic!("Into rate failed, divide-by-zero!");
+                }
+            }
+
             /// Convert between bases for a duration.
             ///
             /// Unfortunately not a `From` impl due to collision with the std lib.
             ///
             /// ```
             /// # use fugit::*;
-            #[doc = concat!("let d1 = Duration::<", stringify!($i), ", 1, 1_00>::from_ticks(1);")]
+            #[doc = concat!("let d1 = Duration::<", stringify!($i), ", 1, 100>::from_ticks(1);")]
             #[doc = concat!("let d2: Duration::<", stringify!($i), ", 1, 1_000> = d1.convert();")]
             ///
             /// assert_eq!(d2.ticks(), 10);
             /// ```
-            // Sooooon const with const panic
-            pub fn convert<const O_NOM: u32, const O_DENOM: u32>(
+            /// Can be used in const contexts. Compilation will fail if the conversion causes overflow
+            /// ```compile_fail
+            /// # use fugit::*;
+            #[doc = concat!("const TICKS: ", stringify!($i), "= ", stringify!($i), "::MAX - 10;")]
+            #[doc = concat!("const D1: Duration::<", stringify!($i), ", 1, 100> = Duration::<", stringify!($i), ", 1, 100>::from_ticks(TICKS);")]
+            /// // Fails conversion due to tick overflow
+            #[doc = concat!("const D2: Duration::<", stringify!($i), ", 1, 200> = D1.convert();")]
+            pub const fn convert<const O_NOM: u32, const O_DENOM: u32>(
                 self,
             ) -> Duration<$i, O_NOM, O_DENOM> {
                 if let Some(v) = self.const_try_into() {
                     v
                 } else {
-                    panic!("Into failed!");
+                    panic!("Convert failed!");
                 }
             }
 
+            /// Convert the Duration to an integer number of nanoseconds.
+            #[inline]
+            pub const fn to_nanos(&self) -> $i {
+                (Helpers::<1, 1_000_000_000, NOM, DENOM>::LD_TIMES_RN as $i * self.ticks)
+                    / Helpers::<1, 1_000_000_000, NOM, DENOM>::RD_TIMES_LN as $i
+            }
+
+            /// Convert the Duration to an integer number of microseconds.
+            #[inline]
+            pub const fn to_micros(&self) -> $i {
+                (Helpers::<1, 1_000_000, NOM, DENOM>::LD_TIMES_RN as $i * self.ticks)
+                    / Helpers::<1, 1_000_000, NOM, DENOM>::RD_TIMES_LN as $i
+            }
+
+            /// Convert the Duration to an integer number of milliseconds.
+            #[inline]
+            pub const fn to_millis(&self) -> $i {
+                (Helpers::<1, 1_000, NOM, DENOM>::LD_TIMES_RN as $i * self.ticks)
+                    / Helpers::<1, 1_000, NOM, DENOM>::RD_TIMES_LN as $i
+            }
+
+            /// Convert the Duration to an integer number of seconds.
+            #[inline]
+            pub const fn to_secs(&self) -> $i {
+                (Helpers::<1, 1, NOM, DENOM>::LD_TIMES_RN as $i * self.ticks)
+                    / Helpers::<1, 1, NOM, DENOM>::RD_TIMES_LN as $i
+            }
+
+            /// Convert the Duration to an integer number of minutes.
+            #[inline]
+            pub const fn to_minutes(&self) -> $i {
+                (Helpers::<60, 1, NOM, DENOM>::LD_TIMES_RN as $i * self.ticks)
+                    / Helpers::<60, 1, NOM, DENOM>::RD_TIMES_LN as $i
+            }
+
+            /// Convert the Duration to an integer number of hours.
+            #[inline]
+            pub const fn to_hours(&self) -> $i {
+                (Helpers::<3_600, 1, NOM, DENOM>::LD_TIMES_RN as $i * self.ticks)
+                    / Helpers::<3_600, 1, NOM, DENOM>::RD_TIMES_LN as $i
+            }
+
+            /// Shorthand for creating a duration which represents nanoseconds.
+            #[inline]
+            pub const fn nanos(val: $i) -> Duration<$i, NOM, DENOM> {
+                Duration::<$i, NOM, DENOM>::from_ticks(
+                    (Helpers::<1, 1_000_000_000, NOM, DENOM>::RD_TIMES_LN as $i * val)
+                        / Helpers::<1, 1_000_000_000, NOM, DENOM>::LD_TIMES_RN as $i,
+                )
+            }
+
             /// Shorthand for creating a duration which represents microseconds.
             #[inline]
             pub const fn micros(val: $i) -> Duration<$i, NOM, DENOM> {
@@ -353,6 +447,16 @@ macro_rules! impl_duration_for_integer {
             }
         }
 
+        // Duration -= Duration
+        impl<const NOM: u32, const DENOM: u32> ops::SubAssign<Duration<$i, NOM, DENOM>>
+            for Duration<$i, NOM, DENOM>
+        {
+            #[inline]
+            fn sub_assign(&mut self, other: Self) {
+                *self = *self - other;
+            }
+        }
+
         // Duration + Duration = Duration (only same base until const_generics_defaults is
         // stabilized)
         impl<const NOM: u32, const DENOM: u32> ops::Add<Duration<$i, NOM, DENOM>>
@@ -370,6 +474,16 @@ macro_rules! impl_duration_for_integer {
             }
         }
 
+        // Duration += Duration
+        impl<const NOM: u32, const DENOM: u32> ops::AddAssign<Duration<$i, NOM, DENOM>>
+            for Duration<$i, NOM, DENOM>
+        {
+            #[inline]
+            fn add_assign(&mut self, other: Self) {
+                *self = *self + other;
+            }
+        }
+
         // integer * Duration = Duration
         impl<const NOM: u32, const DENOM: u32> ops::Mul<Duration<$i, NOM, DENOM>> for u32 {
             type Output = Duration<$i, NOM, DENOM>;
@@ -392,6 +506,16 @@ macro_rules! impl_duration_for_integer {
             }
         }
 
+        // Duration *= integer
+        impl<const NOM: u32, const DENOM: u32> ops::MulAssign<u32>
+            for Duration<$i, NOM, DENOM>
+        {
+            #[inline]
+            fn mul_assign(&mut self, other: u32) {
+                *self = *self * other;
+            }
+        }
+
         // Duration / integer = Duration
         impl<const NOM: u32, const DENOM: u32> ops::Div<u32> for Duration<$i, NOM, DENOM> {
             type Output = Duration<$i, NOM, DENOM>;
@@ -403,6 +527,29 @@ macro_rules! impl_duration_for_integer {
             }
         }
 
+        // Duration /= integer
+        impl<const NOM: u32, const DENOM: u32> ops::DivAssign<u32>
+            for Duration<$i, NOM, DENOM>
+        {
+            #[inline]
+            fn div_assign(&mut self, other: u32) {
+                *self = *self / other;
+            }
+        }
+
+        // Duration / Duration = integer
+        impl<const L_NOM: u32, const L_DENOM: u32, const R_NOM: u32, const R_DENOM: u32> ops::Div<Duration<$i, R_NOM, R_DENOM>>
+            for Duration<$i, L_NOM, L_DENOM>
+        {
+            type Output = $i;
+
+            #[inline]
+            fn div(self, other: Duration<$i, R_NOM, R_DENOM>) -> Self::Output {
+                let conv: Duration<$i, R_NOM, R_DENOM> = self.convert();
+                conv.ticks / other.ticks
+            }
+        }
+
         #[cfg(feature = "defmt")]
         impl<const NOM: u32, const DENOM: u32> defmt::Format for Duration<$i, NOM, DENOM>
         {
@@ -495,6 +642,16 @@ impl<const NOM: u32, const DENOM: u32> ops::Sub<Duration<u32, NOM, DENOM>>
     }
 }
 
+// Duration -= Duration (to make shorthands work, until const_generics_defaults is stabilized)
+impl<const NOM: u32, const DENOM: u32> ops::SubAssign<Duration<u32, NOM, DENOM>>
+    for Duration<u64, NOM, DENOM>
+{
+    #[inline]
+    fn sub_assign(&mut self, other: Duration<u32, NOM, DENOM>) {
+        *self = *self - other;
+    }
+}
+
 // Duration + Duration = Duration (to make shorthands work, until const_generics_defaults is
 // stabilized)
 impl<const NOM: u32, const DENOM: u32> ops::Add<Duration<u32, NOM, DENOM>>
@@ -514,6 +671,16 @@ impl<const NOM: u32, const DENOM: u32> ops::Add<Duration<u32, NOM, DENOM>>
     }
 }
 
+// Duration += Duration (to make shorthands work, until const_generics_defaults is stabilized)
+impl<const NOM: u32, const DENOM: u32> ops::AddAssign<Duration<u32, NOM, DENOM>>
+    for Duration<u64, NOM, DENOM>
+{
+    #[inline]
+    fn add_assign(&mut self, other: Duration<u32, NOM, DENOM>) {
+        *self = *self + other;
+    }
+}
+
 impl<const L_NOM: u32, const L_DENOM: u32, const R_NOM: u32, const R_DENOM: u32>
     PartialOrd<Duration<u32, R_NOM, R_DENOM>> for Duration<u64, L_NOM, L_DENOM>
 {
@@ -556,6 +723,9 @@ impl<const L_NOM: u32, const L_DENOM: u32, const R_NOM: u32, const R_DENOM: u32>
 
 /// Extension trait for simple short-hands for u32 Durations
 pub trait ExtU32 {
+    /// Shorthand for creating a duration which represents nanoseconds.
+    fn nanos<const NOM: u32, const DENOM: u32>(self) -> Duration<u32, NOM, DENOM>;
+
     /// Shorthand for creating a duration which represents microseconds.
     fn micros<const NOM: u32, const DENOM: u32>(self) -> Duration<u32, NOM, DENOM>;
 
@@ -573,6 +743,11 @@ pub trait ExtU32 {
 }
 
 impl ExtU32 for u32 {
+    #[inline]
+    fn nanos<const NOM: u32, const DENOM: u32>(self) -> Duration<u32, NOM, DENOM> {
+        Duration::<u32, NOM, DENOM>::nanos(self)
+    }
+
     #[inline]
     fn micros<const NOM: u32, const DENOM: u32>(self) -> Duration<u32, NOM, DENOM> {
         Duration::<u32, NOM, DENOM>::micros(self)
@@ -601,6 +776,9 @@ impl ExtU32 for u32 {
 
 /// Extension trait for simple short-hands for u64 Durations
 pub trait ExtU64 {
+    /// Shorthand for creating a duration which represents nanoseconds.
+    fn nanos<const NOM: u32, const DENOM: u32>(self) -> Duration<u64, NOM, DENOM>;
+
     /// Shorthand for creating a duration which represents microseconds.
     fn micros<const NOM: u32, const DENOM: u32>(self) -> Duration<u64, NOM, DENOM>;
 
@@ -618,6 +796,11 @@ pub trait ExtU64 {
 }
 
 impl ExtU64 for u64 {
+    #[inline]
+    fn nanos<const NOM: u32, const DENOM: u32>(self) -> Duration<u64, NOM, DENOM> {
+        Duration::<u64, NOM, DENOM>::nanos(self)
+    }
+
     #[inline]
     fn micros<const NOM: u32, const DENOM: u32>(self) -> Duration<u64, NOM, DENOM> {
         Duration::<u64, NOM, DENOM>::micros(self)
